@@ -13,47 +13,25 @@ package inc::MBX::Alien::FLTK::Platform::Unix;
     sub configure {
         my ($self, @args) = @_;
         $self->quiet(1);
-        $self->SUPER::configure();    # Get basic config data
+        $self->SUPER::configure(@args)
+            if !grep {m[no_base]} @args;    # Get basic config data
+        $self->notes(uname => `uname`);
         $self->notes(
             os_ver => ${
                 my $x = `uname -r`;
                     $x =~ s|\D||g;
                     \$x
-                }
+                },
         );
 
         # Asssumed true since this is *nix
-        $self->notes('define')->{'USE_X11'} = !grep {m[^no_x11$]} @args;
-        print "have pthread... yes (assumed)\n";
-        $self->notes('define')->{'HAVE_PTHREAD'} = 1;
-        $self->notes('ldflags' => $self->notes('ldflags') . ' -lpthread ');
+        $self->notes('define')->{'USE_X11'} = 0;    # default
         $self->notes('define')->{'HAVE_SYS_NDIR_H'}
-            = ($self->find_h('sys/ndir.h') ? 1 : undef);
+            = ($self->assert_lib({headers => ['sys/ndir.h']}) ? 1 : undef);
         $self->notes('define')->{'HAVE_SYS_DIR_H'}
-            = ($self->find_h('sys/dir.h') ? 1 : undef);
+            = ($self->assert_lib({headers => ['sys/dir.h']}) ? 1 : undef);
         $self->notes('define')->{'HAVE_NDIR_H'}
-            = ($self->find_h('ndir.h') ? 1 : undef);
-        {
-            print
-                'Checking whether we have the POSIX compatible scandir() prototype... ';
-            my $obj = $self->compile({code => <<'' });
-#include <dirent.h>
-int func (const char *d, dirent ***list, void *sort) {
-    int n = scandir(d, list, 0, (int(*)(const dirent **, const dirent **))sort);
-}
-int main ( ) {
-    return 0;
-}
-
-            if ($obj ? 1 : 0) {
-                print "yes\n";
-                $self->notes('define')->{'HAVE_SCANDIR_POSIX'} = 1;
-            }
-            else {
-                print "no\n";
-                $self->notes('define')->{'HAVE_SCANDIR_POSIX'} = undef;
-            }
-        }
+            = ($self->assert_lib({headers => ['ndir.h']}) ? 1 : undef);
         {
             print "Checking string functions...\n";
             if (($self->notes('os') =~ m[^hpux$]i)
@@ -75,59 +53,6 @@ int main ( ) {
                 $self->notes('define')->{'HAVE_VNPRINTF'} = undef;
             }
         }
-        {
-            my %functions = (
-                strdup      => 'HAVE_STRDUP',
-                strcasecmp  => 'HAVE_STRCASECMP',
-                strncasecmp => 'HAVE_STRNCASECMP',
-                strlcat     => 'HAVE_STRLCRT',
-
-                #strlcpy     => 'HAVE_STRLCPY'
-            );
-            for my $func (keys %functions) {
-                printf 'Checking for %s... ', $func;
-                my $obj = $self->compile({code => <<""});
-/* Define $func to an innocuous variant, in case <limits.h> declares $func.
-   For example, HP-UX 11i <limits.h> declares gettimeofday.  */
-#define $func innocuous_$func
-/* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char $func (); below.
-    Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-    <limits.h> exists even on freestanding compilers.  */
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
-#undef $func
-/* Override any GCC internal prototype to avoid an error.
-   Use char because int might match the return type of a GCC
-   builtin and then its argument prototype would still apply.  */
-#ifdef __cplusplus
-extern "C"
-#endif
-char $func ();
-/* The GNU C library defines this for functions which it implements
-    to always fail with ENOSYS.  Some functions are actually named
-    something starting with __ and the normal name is an alias.  */
-#if defined __stub_$func || defined __stub___$func
-choke me
-#endif
-int main () {
-    return $func ();
-    return 0;
-}
-
-                if ($obj) {
-                    print "yes\n";
-                    $self->notes('define')->{$functions{$func}} = 1;
-                }
-                else {
-                    print "no\n";
-                    $self->notes('define')->{$functions{$func}} = undef;
-                }
-            }
-        }
         {
 
             # Use the X overlay extension for MenuWindow and Tooltips. Pretty
@@ -142,8 +67,8 @@ int main () {
             else { print "no\n" }
         }
         {    # X11 stuff
+            last if grep {m[^no_x11$]} @args;
             {
-                last if grep {m[^no_x11$]} @args;
                 $self->notes('define')->{'USE_X11'} = 1;
                 print 'Checking for X11 libs... ';
                 my $can_haz_x11 = 0;
@@ -178,21 +103,23 @@ If I'm just missing something... patches welcome.
             }
             {
                 print 'Checking for Xcursor libs... ';
-                $self->notes('define')->{'USE_XCURSOR'} = 0;
+                $self->notes('define')->{'USE_XCURSOR'} = undef;
                 for my $format ($self->_x11_()) {
                     my $incdir = sprintf $format, 'include';
                     my $libdir = sprintf $format, 'lib';
                     if ($self->assert_lib(
-                                     {libs     => ['Xcursor'],
-                                      lib_dirs => [$libdir],
-                                      headers  => ['X11/Xcursor/Xcursor.h'],
-                                      include_dirs => [$incdir]
-                                     }
+                            {   libs         => ['Xcursor'],
+                                lib_dirs     => [$libdir],
+                                headers      => ['X11/Xcursor/Xcursor.h'],
+                                include_dirs => [$incdir],
+
+            #code => 'int main(){return XcursorImageLoadCursor (); return 0;}'
+                            }
                         )
                         )
                     {   $self->notes('include_dirs')->{_abs($incdir)}++;
-                        $self->notes('ldflags' => " -L$libdir -lXcursor  "
-                                     . $self->notes('ldflags'));
+                        $self->notes(  'ldflags' => $self->notes('ldflags')
+                                     . " -L$libdir -lXcursor");
                         $self->notes('define')->{'USE_XCURSOR'} = 1;
                         print "okay\n";
                         last;
@@ -200,8 +127,7 @@ If I'm just missing something... patches welcome.
                 }
                 if (!$self->notes('define')->{'USE_XCURSOR'}) {
                     $self->_error({stage   => 'configure',
-                                   fatal   => 1,
-                                   exit    => 1,
+                                   fatal   => 0,
                                    message => <<'' });
 Failed to find the XCursor libs. You probably need to install the X11
 development package first. On Debian Linux, these are the packages libx11-dev,
@@ -228,8 +154,8 @@ x-dev, and libxcursor-dev. If I'm just missing something... patches welcome.
                         )
                         )
                     {   $self->notes('include_dirs')->{_abs($incdir)}++;
-                        $self->notes('ldflags' => " -L$libdir -lXext -lXi "
-                                     . $self->notes('ldflags'));
+                        $self->notes(  'ldflags' => $self->notes('ldflags')
+                                     . " -L$libdir -lXi -lXext");
                         $Xi_okay = 1;
                         print "okay\n";
                         last XI;
@@ -238,6 +164,7 @@ x-dev, and libxcursor-dev. If I'm just missing something... patches welcome.
                 if (!$Xi_okay) {
                     $self->_error({stage   => 'configure',
                                    fatal   => 1,
+                                   exit    => 1,
                                    message => <<'' });
 Failed to find the XInput Extension. You probably need to install the XInput
 Extension development package first. On Debian Linux, this is the libxi-dev
@@ -247,7 +174,7 @@ package. If I'm just missing something... patches welcome.
             }
         }
     GL: {
-            last if grep {m[^no_gl$]} @args;
+            last GL if grep {m[^no_gl$]} @args;
             print 'Checking for GL... ';
             my $GL_LIB = '';
             $self->notes('define')->{'HAVE_GL'} = 0;
@@ -285,12 +212,15 @@ package. If I'm just missing something... patches welcome.
                 }
                 else { print "no\n" }
             }
-            $self->notes(GL => $GL_LIB);
+            $self->notes(GL => '');
             for my $lib (keys %{$self->notes('libs_source')}) {
                 $self->notes('libs_source')->{$lib}{'disabled'}++
-                    if $lib =~ m[gl$]i;
+                    if $lib =~ m[gl]i;
             }
         }
+        print "have pthread... yes (assumed)\n";
+        $self->notes('define')->{'HAVE_PTHREAD'} = 1;
+        $self->notes('ldflags' => $self->notes('ldflags') . ' -lpthread ');
         $self->quiet(0);
         return 1;
     }
